/* (C) 2022 YiRing, Inc. */
package com.yiring.app.design.strategy.rule;

import com.yiring.app.constant.alarm.RelevanceParamEnum;
import com.yiring.app.design.strategy.IScanAlarmStrategy;
import com.yiring.app.param.location.fence.LocationFenceJobParam;
import com.yiring.app.vo.location.fence.LocationFenceJobVo;
import java.util.concurrent.ConcurrentHashMap;
import lombok.extern.slf4j.Slf4j;

/**
 * @author tml
 * @version 1.0
 * @date 2022/5/14 17:51
 */
@Slf4j
public class ScanAlarmContext {

    private static final ConcurrentHashMap<Integer, IScanAlarmStrategy> MAP = new ConcurrentHashMap<>(10);

    public static void register(Integer relevanceParam, IScanAlarmStrategy strategy) {
        MAP.put(relevanceParam, strategy);
    }

    public static LocationFenceJobVo scanAlarm(Integer relevanceParam, LocationFenceJobParam param) {
        if (
            relevanceParam == null || relevanceParam > RelevanceParamEnum.MAX || relevanceParam < RelevanceParamEnum.MIN
        ) {
            log.warn("ScanAlarmContext.scanAlarm报警类型的关联参数异常, relevanceParam:[{}]", relevanceParam);
            throw new RuntimeException("报警类型的关联参数异常");
        }
        IScanAlarmStrategy strategy = MAP.get(relevanceParam);
        return strategy.scanAlarm(param);
    }
}
