/* (C) 2022 YiRing, Inc. */
package com.yiring.app.excel.location.fence;

import com.github.liaochong.myexcel.core.annotation.ExcelColumn;
import com.github.liaochong.myexcel.core.annotation.ExcelModel;
import com.yiring.app.constant.alarm.FenceTypeEnum;
import com.yiring.app.domain.location.LocationFenceAlarm;
import java.io.Serial;
import java.io.Serializable;
import java.time.LocalDateTime;
import java.util.stream.Collectors;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

/**
 * @author tml
 * @version 1.0
 * @date 2022/5/17 17:23
 */
@ExcelModel
@Data
@AllArgsConstructor
@NoArgsConstructor
@Builder
public class FenceAlarmExcel implements Serializable {

    @Serial
    private static final long serialVersionUID = 4526095986813965381L;

    @ExcelColumn(title = "地图名称", width = 10)
    private String mapName;

    @ExcelColumn(title = "围栏名称", width = 10)
    private String fenceName;

    @ExcelColumn(title = "围栏类别", width = 10)
    private String fenceTypeName;

    @ExcelColumn(title = "报警人员", width = 10)
    private String realName;

    @ExcelColumn(title = "标签号", width = 10)
    private String tagId;

    @ExcelColumn(title = "报警开始时间", width = 15)
    private LocalDateTime startTime;

    @ExcelColumn(title = "报警结束时间", width = 15)
    private LocalDateTime endTime;

    @ExcelColumn(title = "报警类型", width = 10)
    private String alarmTypeName;

    @ExcelColumn(title = "接收人", width = 15)
    private String recipient;

    @ExcelColumn(title = "报警状态", width = 10)
    private String statusName;

    public static FenceAlarmExcel transform(LocationFenceAlarm fenceAlarm) {
        String recipient = fenceAlarm
            .getPushLogs()
            .stream()
            .map(e -> e.getUser().getRealName())
            .distinct()
            .collect(Collectors.joining(", "));
        return FenceAlarmExcel
            .builder()
            .fenceName(fenceAlarm.getFence().getName())
            .fenceTypeName(FenceTypeEnum.getByCode(fenceAlarm.getFence().getFenceType()))
            .realName(fenceAlarm.getUser().getRealName())
            .tagId(fenceAlarm.getTag().getCode())
            .startTime(fenceAlarm.getStartTime())
            .endTime(fenceAlarm.getEndTime())
            .alarmTypeName(fenceAlarm.getType().getName())
            .recipient(recipient)
            .statusName(fenceAlarm.getStatus().text())
            .build();
    }
}
