/* (C) 2022 YiRing, Inc. */
package com.yiring.app.param.workArea;

import com.yiring.common.constant.RegEx;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serial;
import java.io.Serializable;
import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.Pattern;
import javax.validation.constraints.Size;
import lombok.*;
import lombok.experimental.FieldDefaults;

/**
 * @author tzl
 * @version 1.0
 * @description:
 * @date 2022/5/21 9:42
 */
@ApiModel("WorkAreaParam")
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@FieldDefaults(level = AccessLevel.PRIVATE)
public class WorkAreaParam implements Serializable {

    @Serial
    private static final long serialVersionUID = 5907859647052875421L;

    @ApiModelProperty(value = "工区名称", example = "工业区", required = true)
    @NotEmpty(message = "工区名称不能为空")
    @Size(max = 10)
    String workAreaName;

    @ApiModelProperty(value = "消抖阈值（秒）", example = "1", required = true)
    Integer threshold;

    @ApiModelProperty(value = "超时时间（秒）", example = "1", required = true)
    Integer timeout;

    @ApiModelProperty(value = "负责人", example = "1")
    String personInCharge;

    @ApiModelProperty(value = "联系电话", example = "17674741309")
    @Pattern(regexp = RegEx.MOBILE, message = "请输入正确的联系电话")
    String mobile;

    @ApiModelProperty(value = "摄像头id", example = "1", required = true)
    Long videoId;
}
