/* (C) 2022 YiRing, Inc. */
package com.yiring.app.service.district;

import com.yiring.app.param.district.DistrictAddParam;
import com.yiring.app.param.district.DistrictModifyParam;
import com.yiring.app.param.district.DistrictRealtimeConditionParam;
import com.yiring.app.vo.district.DistrictDetailsVo;
import com.yiring.app.vo.district.DistrictUserVo;
import com.yiring.app.vo.district.DistrictVo;
import com.yiring.common.core.Result;
import com.yiring.common.param.IdParam;
import com.yiring.common.vo.PageVo;

/**
 * 区域信息service
 * @author tml
 * @version 1.0
 * @date 2022/4/26 13:42
 */
public interface DistrictService {
    /**
     * 添加一个区域信息
     * @param param 区域信息
     * @return 是否成功
     */
    Result<String> addDistrict(DistrictAddParam param);

    /**
     * 修改一条区域信息
     * @param param 区域信息
     * @return 是否成功
     */
    Result<String> modifyDistrict(DistrictModifyParam param);

    /**
     * 删除一条区域信息
     * @param idParam 区域id
     * @return 是否成功
     */
    Result<String> removeDistrict(IdParam idParam);

    /**
     * 根据名称模糊查询
     * @param name 名称
     * @return 区域信息
     */
    Result<PageVo<DistrictVo>> findByNameLike(String name);

    /**
     * 查询实时区域列表信息
     * @param param 条件
     * @return 区域列表
     */
    Result<PageVo<DistrictDetailsVo>> findRealtimeList(DistrictRealtimeConditionParam param);

    /**
     * 查询区域内员工数量
     * @param param 条件
     * @return 区域列表
     */
    Result<PageVo<DistrictUserVo>> findDistrictUser(DistrictRealtimeConditionParam param);
}
