/* (C) 2022 YiRing, Inc. */
package com.yiring.app.util;

import com.yiring.common.constant.RegEx;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import java.util.ArrayList;
import java.util.List;

/**
 * @author tml
 * @version 1.0
 * @date 2022/5/14 14:06
 */
public class TimeUtil {

    public static final List<String> WEEK = new ArrayList<>();

    static {
        WEEK.add("星期一");
        WEEK.add("星期二");
        WEEK.add("星期三");
        WEEK.add("星期四");
        WEEK.add("星期五");
        WEEK.add("星期六");
        WEEK.add("星期日");
    }

    /**
     * 判断一个时间是否在配置的时间内
     * @param time 判断的时间
     * @param beginTime 配置的开始时间
     * @param endTime 配置的结束时间
     * @return true:在 false:不在
     */
    public static boolean judgeWeekTime(LocalDateTime time, String beginTime, String endTime) {
        if (!beginTime.matches(RegEx.WEEK_TIME_RULE) || !endTime.matches(RegEx.WEEK_TIME_RULE)) {
            throw new IllegalArgumentException("时间格式不正确");
        }
        DateTimeFormatter pattern = DateTimeFormatter.ofPattern("E HH:mm:ss");
        String source = time.format(pattern);
        int beginWeek = transform(beginTime.charAt(2));
        int endWeek = transform(endTime.charAt(2));
        int nowWeek = transform(source.charAt(1));

        String beginHour = beginTime.substring(4, 6);
        String endHour = endTime.substring(4, 6);
        String nowHour = source.substring(3, 5);

        String beginMinute = beginTime.substring(7, 9);
        String endMinute = endTime.substring(7, 9);
        String nowMinute = source.substring(6, 8);

        String beginSecond = beginTime.substring(10);
        String endSecond = endTime.substring(10);
        String nowSecond = source.substring(9);

        String beginString = beginWeek + beginHour + beginMinute + beginSecond;
        String endString = endWeek + endHour + endMinute + endSecond;
        String nowString = nowWeek + nowHour + nowMinute + nowSecond;
        int begin = Integer.parseInt(beginString);
        int end = Integer.parseInt(endString);
        int now = Integer.parseInt(nowString);
        return now >= begin && now <= end;
    }

    public static boolean judgeWeek(LocalDateTime time, String week) {
        if (week.matches(RegEx.WEEK_RULE)) {
            throw new IllegalArgumentException("星期格式不正确");
        }
        DateTimeFormatter pattern = DateTimeFormatter.ofPattern("E");
        String timeFormat = time.format(pattern);
        char a = timeFormat.charAt(1);
        char b = week.charAt(2);
        return a == b;
    }

    public static boolean judgeTime(LocalDateTime time, String beginTime, String endTime) {
        DateTimeFormatter pattern = DateTimeFormatter.ofPattern("HH:mm:ss");
        String source = time.format(pattern);

        String beginHour = beginTime.substring(0, 2);
        String endHour = endTime.substring(0, 2);
        String nowHour = source.substring(0, 2);

        String beginMinute = beginTime.substring(3, 5);
        String endMinute = endTime.substring(3, 5);
        String nowMinute = source.substring(3, 5);

        String beginSecond = beginTime.substring(6);
        String endSecond = endTime.substring(6);
        String nowSecond = source.substring(6);

        String beginString = beginHour + beginMinute + beginSecond;
        String endString = endHour + endMinute + endSecond;
        String nowString = nowHour + nowMinute + nowSecond;
        int begin = Integer.parseInt(beginString);
        int end = Integer.parseInt(endString);
        int now = Integer.parseInt(nowString);
        return now >= begin && now <= end;
    }

    private static int transform(char source) {
        return switch (source) {
            case '一' -> 1;
            case '二' -> 2;
            case '三' -> 3;
            case '四' -> 4;
            case '五' -> 5;
            case '六' -> 6;
            case '日' -> 7;
            default -> 1;
        };
    }
}
