/* (C) 2022 YiRing, Inc. */
package com.yiring.app.vo.risk;

import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import com.yiring.app.domain.risk.RiskWarn;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serial;
import java.io.Serializable;
import java.util.List;
import java.util.stream.Collectors;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.locationtech.jts.geom.Point;

/**
 * @author tml
 * @version 1.0
 * @date 2022/5/23 16:06
 */
@ApiModel("风险预警管理")
@Data
@AllArgsConstructor
@NoArgsConstructor
@Builder
public class RiskWarnDetailVo implements Serializable {

    @Serial
    private static final long serialVersionUID = 519127002530795898L;

    @JsonSerialize(using = ToStringSerializer.class)
    @ApiModelProperty(value = "id", example = "1")
    private Long id;

    @ApiModelProperty(value = "工区名称", example = "组装工区")
    private String workAreaName;

    @ApiModelProperty(value = "经纬度", dataType = "java.lang.String")
    private Point point;

    @ApiModelProperty(value = "安装位置", example = "组装厂区二楼")
    private String install;

    @ApiModelProperty(value = "监控参数", example = "有毒气体报警器")
    private String monitoring;

    @ApiModelProperty(value = "位号", example = "AT-4736")
    private String locationNum;

    @ApiModelProperty(value = "量程", example = "0-100PPm")
    private String range;

    @ApiModelProperty(value = "量程单位", example = "PPm")
    private String unit;

    @ApiModelProperty(value = "是否启用", example = "true")
    private Boolean enable;

    private List<ThresholdVo> thresholdVos;

    public static RiskWarnDetailVo transform(RiskWarn riskWarn) {
        List<ThresholdVo> list = riskWarn
            .getThresholds()
            .stream()
            .map(ThresholdVo::transform)
            .collect(Collectors.toList());
        String range = riskWarn.getMin() + "-" + riskWarn.getMax();
        return RiskWarnDetailVo
            .builder()
            .id(riskWarn.getId())
            .workAreaName(riskWarn.getWorkArea().getWorkAreaName())
            .point(riskWarn.getPoint())
            .install(riskWarn.getInstall())
            .monitoring(riskWarn.getMonitoring())
            .locationNum(riskWarn.getLocationNum())
            .range(range)
            .unit(riskWarn.getUnit())
            .enable(riskWarn.getEnable())
            .thresholdVos(list)
            .build();
    }
}
