/* (C) 2022 YiRing, Inc. */
package com.yiring.app.vo.visitor;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serial;
import java.io.Serializable;
import java.time.LocalDateTime;
import lombok.*;
import lombok.experimental.FieldDefaults;
import org.hibernate.annotations.Comment;

/**
 * @author tzl
 * 2022/4/11 14:52
 */
@ApiModel("CarVo")
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@FieldDefaults(level = AccessLevel.PRIVATE)
public class CarVo implements Serializable {

    @Serial
    private static final long serialVersionUID = -1778680629828674385L;

    @JsonSerialize(using = ToStringSerializer.class)
    @ApiModelProperty(value = "主键id", example = "1458555485552")
    Long id;

    @ApiModelProperty(value = "车牌号码", example = "湘A99999")
    String carNum;

    @ApiModelProperty(value = "车辆类型", example = "1")
    String carType;

    @ApiModelProperty(value = "标签卡", example = "DT8875666")
    String labelCard;

    @Comment("司机名称")
    @ApiModelProperty(value = "司机名称", example = "张三")
    String driverName;

    @Comment("司机电话")
    @ApiModelProperty(value = "司机电话", example = "17674741309")
    String mobile;

    @Comment("所属公司")
    @ApiModelProperty(value = "所属公司", example = "壹润科技")
    String orgId;

    @ApiModelProperty(value = "被访人电话", example = "17674741309")
    String intervieweeMobile;

    @Comment("被访人姓名")
    @ApiModelProperty(value = "被访人姓名", example = "李四")
    String intervieweeName;

    //
    @ApiModelProperty(value = "来访原因", example = "装货")
    String reason;

    @ApiModelProperty(value = "发卡时间", example = "2022-04-11 17:25:33")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    LocalDateTime cardSendTime;
}
