/* (C) 2022 YiRing, Inc. */
package com.yiring.app.web.key;

import com.yiring.app.param.key.KeyAlarmRuleAddParam;
import com.yiring.app.param.key.KeyAlarmRuleExportParam;
import com.yiring.app.param.key.KeyAlarmRuleModifyParam;
import com.yiring.app.param.key.KeyAlarmRulePageParam;
import com.yiring.app.service.key.KeyAlarmRuleService;
import com.yiring.app.vo.key.KeyAlarmRuleVo;
import com.yiring.common.core.Result;
import com.yiring.common.param.IdParam;
import com.yiring.common.param.PageParam;
import com.yiring.common.vo.PageVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

/**
 * 按键报警规则控制器
 *
 * @author LJ-2204
 * @date 2022/5/6
 */

@Validated
@SuppressWarnings({ "deprecation" })
@Api(tags = "按键报警规则", description = "KeyAlarmRule")
@RestController
@RequestMapping("/key/alarm/rules")
public class KeyAlarmRuleController {

    @Resource
    KeyAlarmRuleService keyAlarmRuleService;

    @ApiOperation("新增报警规则")
    @PostMapping("add")
    public Result<String> add(@Valid KeyAlarmRuleAddParam keyAlarmRuleAddParam) {
        return keyAlarmRuleService.add(keyAlarmRuleAddParam);
    }

    @ApiOperation("删除报警规则")
    @DeleteMapping("delete")
    public Result<String> delete(@Valid IdParam idParam) {
        return keyAlarmRuleService.delete(idParam);
    }

    @ApiOperation("更新报警规则")
    @PutMapping("modify")
    public Result<String> modify(@Valid KeyAlarmRuleModifyParam keyAlarmRuleModifyParam) {
        return keyAlarmRuleService.modify(keyAlarmRuleModifyParam);
    }

    @ApiOperation("导出")
    @GetMapping("export")
    public void export(@Valid KeyAlarmRuleExportParam keyAlarmRuleExportParam, HttpServletResponse response) {
        keyAlarmRuleService.export(keyAlarmRuleExportParam, response);
    }

    @ApiOperation("表格查询")
    @GetMapping("page")
    public Result<PageVo<KeyAlarmRuleVo>> page(
        @Valid KeyAlarmRulePageParam keyAlarmRulePageParam,
        @Valid PageParam pageParam
    ) {
        return keyAlarmRuleService.page(keyAlarmRulePageParam, pageParam);
    }
}
