/* (C) 2022 YiRing, Inc. */
package com.yiring.app.web.risk;

import com.yiring.app.param.risk.RiskPushConditionParam;
import com.yiring.app.param.risk.RiskPushSaveParam;
import com.yiring.app.service.risk.RiskPushService;
import com.yiring.app.vo.risk.RiskPushVo;
import com.yiring.common.core.Result;
import com.yiring.common.param.IdParam;
import com.yiring.common.param.PageParam;
import com.yiring.common.vo.PageVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import javax.annotation.Resource;
import javax.validation.Valid;
import lombok.extern.slf4j.Slf4j;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

/**
 * 风险推送
 *
 * @author LJ-2204
 * @date 2022/5/23
 */

@Slf4j
@Validated
@SuppressWarnings({ "deprecation" })
@Api(tags = "风险推送", description = "RiskPush")
@RestController
@RequestMapping("/risk/push/")
public class RiskPushController {

    @Resource
    RiskPushService riskPushService;

    @ApiOperation("新增")
    @PostMapping("add")
    public Result<String> add(@Valid RiskPushSaveParam param) {
        return riskPushService.add(param);
    }

    @ApiOperation("删除")
    @DeleteMapping("delete")
    public Result<String> delete(@Valid IdParam idParam) {
        return riskPushService.delete(idParam);
    }

    @ApiOperation("分页查询")
    @GetMapping("page")
    public Result<PageVo<RiskPushVo>> page(@Valid RiskPushConditionParam param, @Valid PageParam pageParam) {
        return riskPushService.page(param, pageParam);
    }

    @ApiOperation("查询详情")
    @GetMapping("info")
    public Result<RiskPushVo> info(@Valid IdParam idParam) {
        return riskPushService.info(idParam);
    }
}
