/* (C) 2022 YiRing, Inc. */
package com.yiring.auth.service;

import cn.hutool.extra.spring.SpringUtil;
import com.aliyuncs.DefaultAcsClient;
import com.aliyuncs.IAcsClient;
import com.aliyuncs.dysmsapi.model.v20170525.SendSmsRequest;
import com.aliyuncs.dysmsapi.model.v20170525.SendSmsResponse;
import com.aliyuncs.http.MethodType;
import com.aliyuncs.profile.DefaultProfile;
import com.aliyuncs.profile.IClientProfile;
import com.yiring.common.core.Result;
import com.yiring.common.core.Status;
import java.util.Arrays;
import java.util.concurrent.TimeUnit;
import javax.annotation.Resource;
import lombok.AccessLevel;
import lombok.Data;
import lombok.experimental.FieldDefaults;
import lombok.extern.slf4j.Slf4j;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Component;

/**
 * 短信服务
 *
 * @author fangzhimin
 * @date 2018/9/4 15:39
 */

@Slf4j
@Data
@FieldDefaults(level = AccessLevel.PRIVATE)
@Component
@ConfigurationProperties(prefix = "config.sms")
public class MessageService {

    @Resource
    RedisTemplate<String, Object> redisTemplate;

    /**
     * 默认验证码有效期
     */
    Long expired;
    String scOk;
    String product;
    String domain;
    String accessKeyId;
    String accessKeySecret;
    String signName;
    String templateCode;

    /**
     * 发送手机短信验证码
     *
     * @param phone 手机号
     * @return 公共的接口响应内容
     */
    public Result<String> sendSmsCode(String phone) {
        try {
            String environment = "dev";
            if (Arrays.asList(SpringUtil.getActiveProfiles()).contains(environment)) {
                String number = "123456";
                // 将短信验证码存入Redis
                redisTemplate.opsForValue().set(phone, number, expired, TimeUnit.MILLISECONDS);
                return Result.ok(number);
            }

            // 随机数验证码
            String number = (int) ((Math.random() * 9 + 1) * 100000) + "";
            // 超时时间
            System.setProperty("sun.net.client.defaultConnectTimeout", "10000");
            System.setProperty("sun.net.client.defaultReadTimeout", "10000");

            // 初始化
            IClientProfile profile = DefaultProfile.getProfile("cn-hangzhou", accessKeyId, accessKeySecret);
            DefaultProfile.addEndpoint("cn-hangzhou", product, domain);
            IAcsClient acsClient = new DefaultAcsClient(profile);

            // 组装请求对象
            SendSmsRequest request = new SendSmsRequest();
            request.setSysMethod(MethodType.POST);
            request.setPhoneNumbers(phone);
            request.setSignName(signName);
            request.setTemplateCode(templateCode);
            request.setTemplateParam("{\"smsCode\":\"" + number + "\"}");

            // 发送请求，失败会抛出异常
            SendSmsResponse res = acsClient.getAcsResponse(request);
            if (res.getCode() != null && scOk.equals(res.getCode())) {
                // 将短信验证码存入Redis
                redisTemplate.opsForValue().set(phone, number, expired, TimeUnit.MILLISECONDS);
            }

            return Result.no(Status.INTERNAL_SERVER_ERROR, res.getMessage());
        } catch (Exception e) {
            log.error(e.getMessage(), e);
            return Result.no(Status.INTERNAL_SERVER_ERROR);
        }
    }

    /**
     * 销毁验证码
     * @param phone String
     */
    public void deleteCode(String phone) {
        redisTemplate.delete(phone);
    }
}
